# Security Policy

## Supported Versions

| Version | Supported          |
|---------|--------------------|
| 0.0.x   | :white_check_mark: |

## Reporting a Vulnerability

If you find a vulnerability, please open an [issue](https://github.com/truePhilipp/html_to_django/issues).
